@@ -7,6 +7,7 @@ from django.utils import timezone
 from django.utils.dateparse import parse_datetime
 from firebase_token_generator import create_token
 from django.conf import settings
+from django.db.models import get_models
 
 import elasticsearch
 
@@ -17,6 +18,7 @@ from rest_framework import (
     viewsets,
     routers
 )
+from rest_framework.decorators import detail_route
 from rest_framework.permissions import IsAdminUser
 from rest_framework.response import Response
 
@@ -24,11 +26,14 @@ from elastimorphic.models import polymorphic_indexable_registry
 
 from elasticutils.contrib.django import get_es
 
-from bulbs.content.models import Content, Tag, LogEntry
+from bulbs.content.models import Content, Tag, LogEntry, FeatureType
 from bulbs.content.serializers import (
     LogEntrySerializer, PolymorphicContentSerializer,
-    TagSerializer, UserSerializer
+    TagSerializer, UserSerializer, FeatureTypeSerializer
 )
+from bulbs.contributions.serializers import ContributionSerializer
+from bulbs.contributions.models import Contribution
+
 from bulbs.promotion.models import ContentList, ContentListHistory
 from bulbs.promotion.serializers import ContentListSerializer
 
@@ -53,7 +58,7 @@ class ContentViewSet(UncachedResponse, viewsets.ModelViewSet):
     def get_serializer_class(self):
         klass = None
 
-        if hasattr(self, "object"):
+        if getattr(self, "object", None):
             klass = self.object.__class__
         elif "doctype" in self.request.REQUEST:
             try:
@@ -164,6 +169,26 @@ class ContentViewSet(UncachedResponse, viewsets.ModelViewSet):
         content = self.get_object()
         return Response({"status": content.get_status()})
 
+    @detail_route(methods=["post", "get"])
+    def contributions(self, request, **kwargs):
+        # Check if the contribution app is installed
+        if Contribution not in get_models():
+            return Response([])
+        queryset = Contribution.objects.filter(content=self.get_object())
+        if request.method == "POST":
+            serializer = ContributionSerializer(
+                queryset,
+                data=request.DATA,
+                many=True,
+                allow_add_remove=True)
+            if not serializer.is_valid():
+                return Response(serializer.errors)
+            serializer.save()
+            return Response(serializer.data)
+        else:
+            serializer = ContributionSerializer(queryset, many=True)
+            return Response(serializer.data)
+
 
 class TagViewSet(UncachedResponse, viewsets.ReadOnlyModelViewSet):
     model = Tag
@@ -265,12 +290,39 @@ class LogEntryViewSet(UncachedResponse, viewsets.ModelViewSet):
         return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
 
 
+class AuthorViewSet(UncachedResponse, viewsets.ReadOnlyModelViewSet):
+
+    serializer_class = UserSerializer
+    model = User
+    filter_backends = (filters.SearchFilter, filters.OrderingFilter)
+    search_fields = ("first_name", "last_name", "username")
+
+    def get_queryset(self):
+        author_filter = getattr(settings, "BULBS_AUTHOR_FILTER", {"is_staff": True})
+        queryset = self.model.objects.filter(**author_filter)
+
+        return queryset
+
+
+class FeatureTypeViewSet(UncachedResponse, viewsets.ReadOnlyModelViewSet):
+
+    serializer_class = FeatureTypeSerializer
+    model = FeatureType
+    filter_backends = (filters.SearchFilter, filters.OrderingFilter)
+    search_fields = ("name", )
+
+
 class MeViewSet(UncachedResponse, viewsets.ReadOnlyModelViewSet):
 
     def retrieve(self, request, *args, **kwargs):
 
         data = UserSerializer().to_native(request.user)
 
+        # add superuser flag only if user is a superuser, putting it here so users can only tell if they are themselves
+        #   superusers
+        if request.user.is_superuser:
+            data['is_superuser'] = True
+
         # attempt to add a firebase token if we have a firebase secret
         secret = getattr(settings, 'FIREBASE_SECRET', None)
         if secret:
@@ -291,5 +343,7 @@ api_v1_router.register(r"content", ContentViewSet, base_name="content")
 api_v1_router.register(r"contentlist", ContentListViewSet, base_name="contentlist")
 api_v1_router.register(r"tag", TagViewSet, base_name="tag")
 api_v1_router.register(r"log", LogEntryViewSet, base_name="logentry")
+api_v1_router.register(r"author", AuthorViewSet, base_name="author")
+api_v1_router.register(r"feature-type", FeatureTypeViewSet, base_name="feature-type")
 api_v1_router.register(r"user", UserViewSet, base_name="user")
 # note: me view is registered in urls.py
